@@ -57,7 +57,7 @@ private:
     QString m_destName;
     bool m_isClass;
     QVariantHash m_changedValues;
-    int m_changes;
+    int m_changes = 0;
 };
 
 #endif
