@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -56,9 +56,7 @@ PrinterOptions::PrinterOptions(const QString &destName, bool isClass, bool isRem
     ui(new Ui::PrinterOptions),
     m_destName(destName),
     m_isClass(isClass),
-    m_isRemote(isRemote),
-    m_ppd(NULL),
-    m_changes(0)
+    m_isRemote(isRemote)
 {
     ui->setupUi(this);
 
@@ -68,7 +66,7 @@ PrinterOptions::PrinterOptions(const QString &destName, bool isClass, bool isRem
 void PrinterOptions::on_autoConfigurePB_clicked()
 {
     QPointer<KCupsRequest> request = new KCupsRequest;
-    request->printCommand(m_destName, "AutoConfigure", i18n("Set Default Options"));
+    request->printCommand(m_destName, QLatin1String("AutoConfigure"), i18n("Set Default Options"));
     request->waitTillFinished();
     if (request) {
         request->deleteLater();
@@ -79,7 +77,7 @@ void PrinterOptions::reloadPPD()
 {
     //     The caller "owns" the file that is created and must unlink the returned filename.
     if (!m_filename.isEmpty()) {
-        unlink(m_filename.toUtf8());
+        unlink(qUtf8Printable(m_filename));
     }
 
     // remove all the options
@@ -109,7 +107,7 @@ void PrinterOptions::reloadPPD()
         return;
     }
     m_filename = request->printerPPD();
-    m_ppd = ppdOpenFile(m_filename.toUtf8());
+    m_ppd = ppdOpenFile(qUtf8Printable(m_filename));
     request->deleteLater();
     if (m_ppd == NULL) {
         qCWarning(PM_CONFIGURE_PRINTER) << "Could not open ppd file:" << m_filename << request->errorMsg();
@@ -185,10 +183,10 @@ void PrinterOptions::createGroups()
         QString text = m_codec->toUnicode(group->text);
 
         // The group box were the options will be laid out
-        QGroupBox *groupBox = new QGroupBox(text, ui->scrollArea);
+        auto groupBox = new QGroupBox(text, ui->scrollArea);
 
         // Create the form layout to put options in
-        QFormLayout *gFormLayout = new QFormLayout(groupBox);
+        auto gFormLayout = new QFormLayout(groupBox);
         gFormLayout->setFormAlignment(Qt::AlignCenter);
         groupBox->setLayout(gFormLayout);
         ui->verticalLayout->addWidget(groupBox);
@@ -205,7 +203,7 @@ void PrinterOptions::createGroups()
             // The python system-config-printer skips this one
             // which has the same data as "PageSize", let's hope
             // they did the right thing
-            if (oKeyword == "PageRegion") {
+            if (oKeyword == QLatin1String("PageRegion")) {
                 continue;
             }
 
@@ -239,9 +237,9 @@ void PrinterOptions::createGroups()
 QWidget* PrinterOptions::pickBoolean(ppd_option_t *option, const QString &keyword, QWidget *parent) const
 {
     Q_UNUSED(keyword)
-    QWidget *widget = new QWidget(parent);
-    QHBoxLayout *layout = new QHBoxLayout(widget);
-    QButtonGroup *radioGroup = new QButtonGroup(widget);
+    auto widget = new QWidget(parent);
+    auto layout = new QHBoxLayout(widget);
+    auto radioGroup = new QButtonGroup(widget);
     widget->setLayout(layout);
 
     int i;
@@ -251,10 +249,10 @@ QWidget* PrinterOptions::pickBoolean(ppd_option_t *option, const QString &keywor
     for (i = 0, choice = option->choices;
          i < option->num_choices;
          ++i, ++choice) {
-        QString choiceName = m_codec->toUnicode(choice->choice);
-        QString cText = m_codec->toUnicode(choice->text);
+        const QString choiceName = m_codec->toUnicode(choice->choice);
+        const QString cText = m_codec->toUnicode(choice->text);
 
-        QRadioButton *button = new QRadioButton(cText, widget);
+        auto button = new QRadioButton(cText, widget);
         button->setChecked(defChoice == choiceName);
         button->setProperty("choice", choiceName);
         // if we are in looking at a remote printer we can't save it
@@ -266,8 +264,7 @@ QWidget* PrinterOptions::pickBoolean(ppd_option_t *option, const QString &keywor
     // store the default choice
     radioGroup->setProperty(DEFAULT_CHOICE, defChoice);
     radioGroup->setProperty("Keyword", keyword);
-    connect(radioGroup, SIGNAL(buttonClicked(QAbstractButton*)),
-            this, SLOT(radioBtClicked(QAbstractButton*)));
+    connect(radioGroup, static_cast<void(QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), this, &PrinterOptions::radioBtClicked);
     return widget;
 }
 
@@ -303,22 +300,22 @@ void PrinterOptions::radioBtClicked(QAbstractButton *button)
 QWidget* PrinterOptions::pickMany(ppd_option_t *option, const QString &keyword, QWidget *parent) const
 {
     Q_UNUSED(keyword)
-    QListView *listView = new QListView(parent);
-    QStandardItemModel *model = new QStandardItemModel(listView);
+    auto listView = new QListView(parent);
+    auto model = new QStandardItemModel(listView);
     listView->setModel(model);
     listView->setItemDelegate(new NoSelectionRectDelegate(listView));
 
     int i;
     ppd_choice_t *choice;
-    QString oDefChoice = m_codec->toUnicode(option->defchoice);
+    const QString oDefChoice = m_codec->toUnicode(option->defchoice);
     // Iterate over the choices in the option
     for (i = 0, choice = option->choices;
          i < option->num_choices;
          ++i, ++choice) {
-        QString cName = m_codec->toUnicode(choice->choice);
-        QString cText = m_codec->toUnicode(choice->text);
+        const QString cName = m_codec->toUnicode(choice->choice);
+        const QString cText = m_codec->toUnicode(choice->text);
 
-        QStandardItem *item = new QStandardItem(cText);
+        auto item = new QStandardItem(cText);
         item->setData(cName);
         item->setCheckable(true);
         item->setEditable(false);
@@ -336,14 +333,14 @@ QWidget* PrinterOptions::pickOne(ppd_option_t *option, const QString &keyword, Q
 {
     int i;
     ppd_choice_t *choice;
-    QString defChoice = m_codec->toUnicode(option->defchoice);
-    QComboBox *comboBox = new QComboBox(parent);
+    const QString defChoice = m_codec->toUnicode(option->defchoice);
+    auto comboBox = new QComboBox(parent);
     // Iterate over the choices in the option
     for (i = 0, choice = option->choices;
          i < option->num_choices;
          ++i, ++choice) {
-        QString cName = m_codec->toUnicode(choice->choice);
-        QString cText = m_codec->toUnicode(choice->text);
+        const QString cName = m_codec->toUnicode(choice->choice);
+        const QString cText = m_codec->toUnicode(choice->text);
 
         comboBox->addItem(cText, cName);
     }
@@ -352,8 +349,7 @@ QWidget* PrinterOptions::pickOne(ppd_option_t *option, const QString &keyword, Q
     comboBox->setProperty("Keyword", keyword);
     comboBox->setCurrentIndex(comboBox->findData(defChoice));
     // connect the signal AFTER setCurrentIndex is called
-    connect(comboBox, SIGNAL(currentIndexChanged(int)),
-            this, SLOT(currentIndexChangedCB(int)));
+    connect(comboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &PrinterOptions::currentIndexChangedCB);
     // if we are in looking at a remote printer we can't save it
     comboBox->setEnabled(!m_isRemote);
     return qobject_cast<QWidget*>(comboBox);
@@ -361,7 +357,7 @@ QWidget* PrinterOptions::pickOne(ppd_option_t *option, const QString &keyword, Q
 
 void PrinterOptions::currentIndexChangedCB(int index)
 {
-    QComboBox *comboBox = qobject_cast<QComboBox*>(sender());
+    auto comboBox = qobject_cast<QComboBox*>(sender());
     bool isDifferent = comboBox->property(DEFAULT_CHOICE).toString() != comboBox->itemData(index);
 
     if (isDifferent != comboBox->property("different").toBool()) {
@@ -395,7 +391,7 @@ PrinterOptions::~PrinterOptions()
     }
 
     if (!m_filename.isEmpty()) {
-        unlink(m_filename.toUtf8());
+        unlink(qUtf8Printable(m_filename));
     }
 
     delete ui;
@@ -404,10 +400,11 @@ PrinterOptions::~PrinterOptions()
 const char *                            /* O - Value of variable */
 PrinterOptions::getVariable(const char *name)    const    /* I - Name of variable */
 {
-    QString keyword = m_codec->toUnicode(name);
-    if (m_customValues.contains(keyword)) {
-        QString value = m_customValues[keyword]->property("currentChoice").toString();
-        return m_codec->fromUnicode(value);
+    const QString keyword = m_codec->toUnicode(name);
+    auto it = m_customValues.constFind(keyword);
+    if (it != m_customValues.constEnd()) {
+        const QString value = it.value()->property("currentChoice").toString();
+        return m_codec->fromUnicode(value).constData();
     } else {
         return NULL;
     }
@@ -709,7 +706,7 @@ void PrinterOptions::save()
     // copy cups-1.4.2/cgi-bin line 3779
     if (!m_filename.isEmpty()) {
         out = cupsTempFile2(tempfile, sizeof(tempfile));
-        in  = cupsFileOpen(m_filename.toUtf8(), "r");
+        in  = cupsFileOpen(qUtf8Printable(m_filename), "r");
 
         if (!in || !out)
         {
@@ -777,7 +774,7 @@ void PrinterOptions::save()
     if (m_isClass) {
         request->addOrModifyClass(m_destName, values);
     } else {
-        request->addOrModifyPrinter(m_destName, values, tempfile);
+        request->addOrModifyPrinter(m_destName, values, QString::fromUtf8(tempfile));
     }
 
     // Disable the widget till the request is processed
@@ -795,14 +792,14 @@ void PrinterOptions::save()
         if (!request->hasError()) {
             // if we succefully save the new ppd we need now to
             // clear our changes
-            QHash<QString, QObject*>::const_iterator i = m_customValues.constBegin();
+            auto i = m_customValues.constBegin();
             while (i != m_customValues.constEnd()) {
-                QString currentChoice;
-                currentChoice = i.value()->property("currentChoice").toString();
+                QObject *obj = i.value();
+                const QString currentChoice = obj->property("currentChoice").toString();
                 // Store the current choice as the default one
-                i.value()->setProperty(DEFAULT_CHOICE, currentChoice);
-                i.value()->setProperty("currentChoice", QVariant());
-                i.value()->setProperty("different", false);
+                obj->setProperty(DEFAULT_CHOICE, currentChoice);
+                obj->setProperty("currentChoice", QVariant());
+                obj->setProperty("different", false);
                 ++i;
             }
             m_changes = 0;
@@ -827,3 +824,5 @@ QString PrinterOptions::currentMakeAndModel() const
 {
     return m_makeAndModel;
 }
+
+#include "moc_PrinterOptions.cpp"
