@@ -100,13 +100,14 @@ public:
                       int row,
                       int column,
                       const QModelIndex &parent) Q_DECL_OVERRIDE;
+    virtual QHash<int,QByteArray> roleNames() const override;
 
     Q_INVOKABLE void setWhichJobs(WhichJobs whichjobs);
     KCupsRequest* modifyJob(int row, JobAction action, const QString &newDestName = QString(), const QModelIndex &parent = QModelIndex());
 
 private slots:
     void getJobs();
-    void getJobFinished();
+    void getJobFinished(KCupsRequest *request);
 
     void jobCompleted(const QString &text,
                       const QString &printerUri,
@@ -138,12 +139,12 @@ private:
     QString jobStatus(ipp_jstate_e job_state);
     void clear();
 
-    KCupsRequest *m_jobRequest;
+    KCupsRequest *m_jobRequest = nullptr;
     QString m_destName;
     QString m_processingJob;
-    int m_whichjobs;
-    WId m_parentId;
-    QStringList m_jobAttributes;
+    QHash<int, QByteArray> m_roles;
+    int m_whichjobs = CUPS_WHICHJOBS_ACTIVE;
+    WId m_parentId = 0;
 };
 
 #endif // JOB_MODEL_H
